@@ -23,16 +23,17 @@ test_that("cdb_fetch works correctly", {
   ))
 })
 
-test_that("cdb_fetch works correctly using internet", {
-  # Check obtaining via internet
-  expect_true(inherits(cdb_fetch("compadre"), "CompadreDB"))
-  expect_true(inherits(cdb_fetch("comadre"), "CompadreDB"))
-  expect_true(inherits(cdb_fetch("compadre", version = "5.0.1"), "CompadreDB"))
-  expect_true(inherits(cdb_fetch("comadre", version = "4.23.3.1"), "CompadreDB"))
-})
-
-x <- cdb_fetch("compadre")
-testthat::expect_true(inherits(x, "CompadreDB"))
-
-x <- cdb_fetch("compadre", flag = FALSE)
-testthat::expect_true(inherits(x, "CompadreDB"))
+#test_that("cdb_fetch works correctly using internet", {
+#  # Check obtaining via internet
+#  expect_true(inherits(cdb_fetch("compadre"), "CompadreDB"))
+#  expect_true(inherits(cdb_fetch("comadre"), "CompadreDB"))
+#  expect_true(inherits(cdb_fetch("compadre", version = "5.0.1"), "CompadreDB"))
+#  expect_true(inherits(cdb_fetch("comadre", version = "4.23.3.1"), "CompadreDB"))
+#
+#
+#x <- cdb_fetch("compadre")
+#testthat::expect_true(inherits(x, "CompadreDB"))
+#
+#x <- cdb_fetch("compadre", flag = FALSE)
+#testthat::expect_true(inherits(x, "CompadreDB"))
+#})
\ No newline at end of file
