@@ -3,8 +3,11 @@ test_that("cdb_unflatten works correctly", {
   CompadreUnflat <- cdb_unflatten(db1)
 
   expect_s4_class(CompadreUnflat, "CompadreDB")
-  expect_equal(CompadreUnflat$SpeciesAuthor, Compadre$SpeciesAuthor)
-  expect_true(all(matA(CompadreUnflat)[[65]] == matA(Compadre)[[65]]))
+  expect_identical(CompadreUnflat$SpeciesAuthor, Compadre$SpeciesAuthor)
+  expect_identical(
+    as.vector(matA(CompadreUnflat)[[65]]),
+    as.vector(matA(Compadre)[[65]])
+  )
 })
 
 
